@@ -22,9 +22,9 @@ del Consejo Superior Bancario (CSB) / Asociación Española de Banca (CSB).
 
 from __future__ import absolute_import
 
-from .csb_file import File, ClosingFile, showInfo
-from .account import Account, ClosingAccount
-from .exchange import Exchange
-from .item import Item
-from .record import Record
-from .transaction import Transaction
+from .csb_file import File, ClosingFile  # noqa: F401
+from .account import Account, ClosingAccount  # noqa: F401
+from .exchange import Exchange  # noqa: F401
+from .item import Item  # noqa: F401
+from .record import RecordSequence  # noqa: F401
+from .transaction import Transaction  # noqa: F401
