@@ -4,36 +4,49 @@ from __future__ import absolute_import
 
 import unittest
 
-from ..homebank import transaction
+from .. import homebank
 from .. import utils
 import datetime
+import decimal
 
 
 class TestHomebankTransaction(unittest.TestCase):
 
     def setUp(self):
         self.tDate = datetime.date(2002, 3, 4)
-        self.value = [self.tDate.strftime("%d-%m-%y"),
-                      '2', '3', '4', '5', '6.00']
+        self.value = [
+            # date
+            self.tDate.strftime("%d-%m-%y"),
+            # mode
+            '2',
+            # info
+            '3',
+            # payee
+            '4',
+            # description
+            '5',
+            # amount
+            '1.10'
+        ]
 
     def test_init(self):
         try:
-            transaction.Transaction()
+            homebank.Transaction()
         except utils.Csb43Exception:
             self.fail("exception not expected")
 
     def test_init_record(self):
 
         with self.assertRaises(utils.Csb43Exception):
-            transaction.Transaction("1;2")
+            homebank.Transaction("1;2")
 
         with self.assertRaises(utils.Csb43Exception):
-            transaction.Transaction(",".join(self.value))
+            homebank.Transaction(",".join(self.value))
 
-        transaction.Transaction(";".join(self.value))
+        homebank.Transaction(";".join(self.value))
 
     def test_properties(self):
-        t = transaction.Transaction(";".join(self.value))
+        t = homebank.Transaction(";".join(self.value))
 
         self.assertEqual(self.tDate.year, t.date.year)
         self.assertEqual(self.tDate.month, t.date.month)
@@ -43,13 +56,13 @@ class TestHomebankTransaction(unittest.TestCase):
         self.assertEqual('3', t.info)
         self.assertEqual('4', t.payee)
         self.assertEqual('5', t.description)
-        self.assertEqual(6, t.amount)
+        self.assertEqual(decimal.Decimal('1.1'), t.amount)
         self.assertIsNone(t.category)
 
         value = list(self.value)
         value.append('7')
 
-        t = transaction.Transaction(";".join(value))
+        t = homebank.Transaction(";".join(value))
 
         self.assertEqual(self.tDate.year, t.date.year)
         self.assertEqual(self.tDate.month, t.date.month)
@@ -59,7 +72,7 @@ class TestHomebankTransaction(unittest.TestCase):
         self.assertEqual('3', t.info)
         self.assertEqual('4', t.payee)
         self.assertEqual('5', t.description)
-        self.assertEqual(6, t.amount)
+        self.assertEqual(decimal.Decimal('1.1'), t.amount)
         self.assertEqual('7', t.category)
 
         t.mode = '23'
@@ -76,7 +89,7 @@ class TestHomebankTransaction(unittest.TestCase):
         t.description = 'description'
         self.assertEqual('description', t.description)
 
-        with self.assertRaises(ValueError):
+        with self.assertRaises(decimal.InvalidOperation):
             t.amount = 'amount'
 
         with self.assertRaises(utils.Csb43Exception):
@@ -84,7 +97,7 @@ class TestHomebankTransaction(unittest.TestCase):
 
         try:
             t.date = self.tDate
-        except:
+        except Exception:
             self.fail("exception not expected")
 
     def test_str(self):
@@ -92,6 +105,6 @@ class TestHomebankTransaction(unittest.TestCase):
         value.append('7')
         value = ";".join(value)
 
-        t = transaction.Transaction(value)
+        t = homebank.Transaction(value)
 
         self.assertEqual(value, str(t))
