@@ -3,8 +3,9 @@ from __future__ import unicode_literals
 from __future__ import absolute_import
 
 import unittest
+from decimal import Decimal
 
-from ..utils import utils
+from .. import utils
 
 
 class TestUtils(unittest.TestCase):
@@ -36,17 +37,17 @@ class TestUtils(unittest.TestCase):
 
         gotten = utils.raw2currency(value, debit=tag)
 
-        self.assertEqual(-1234.56, gotten)
+        self.assertEqual(Decimal('-1234.56'), gotten)
 
         tag = "2"
 
         gotten = utils.raw2currency(value, debit=tag)
 
-        self.assertEqual(1234.56, gotten)
+        self.assertEqual(Decimal('1234.56'), gotten)
 
         value = 123456
 
-        self.assertEqual(1234.56, gotten)
+        self.assertEqual(Decimal('1234.56'), gotten)
 
     def test_check_string(self):
 
@@ -75,7 +76,7 @@ class TestUtils(unittest.TestCase):
     def test_currencyISO(self):
 
         numeric = '978'
-        self.assertEqual('EUR', utils.currencyISO(numeric).letter)
+        self.assertEqual('EUR', utils.currencyISO(numeric).alpha_3)
 
     def test_raw2date(self):
         value = "020304"
