@@ -6,15 +6,23 @@ from __future__ import unicode_literals
 
 from ..i18n import tr as _
 
-BAD_RECORD = lambda x: _(
-    'bad code of record or unexpected length: >>>%s<<<') % x
 
-CURRENCY_EXPECTED = lambda x: _("pycountry.Currencies object or a valid"
-                                " ISO 4217 code expected,"
-                                " but %s found") % x
+def BAD_RECORD(x):
+    return _('bad code of record or unexpected length: >>>%s<<<') % x
+
+
+def CURRENCY_EXPECTED(x):
+    return _(
+        "pycountry.Currencies object or a valid"
+        " ISO 4217 code expected,"
+        " but %s found") % x
+
+
+def INCOMPATIBLE_OBJECT(x):
+    return _(
+        "incompatible object '%s', type(s) %s expected"
+    ) % (x[0], ', '.join(x[1:]))
 
-INCOMPATIBLE_OBJECT = lambda x: _(
-    "incompatible object '%s', type(s) %s expected") % (x[0], ', '.join(x[1:]))
 
 # Account ID
 T_BANK_CODE = _('bank_code')
